@@ -12,12 +12,13 @@ def create_project(name):
     os.makedirs(path)
     os.makedirs(path / name)
     os.makedirs(path / 'tests')
-    os.makedirs(path / 'docs')
+    # os.makedirs(path / 'docs') # TODO: Autocreate documentation
 
     write_file(path / 'setup.py', SETUP_PY_TEMPLATE.replace('PROJECT_NAME', name))
 
     source = SOURCE_TEMPLATE.replace('PROJECT_NAME', name)
     write_file(path / name / 'main.py', source)
+    write_file(path / name / '__init__.py', '')
 
     test = TEST_TEMPLATE.replace('PROJECT_NAME', name).replace('MODULE_NAME', 'main')
     write_file(path / 'tests' / 'test_main.py', test)
