@@ -1,5 +1,6 @@
 import click
 from manati.create import create_project
+from manati.apropos import help_tests, help_install
 
 
 @click.group('manati')
@@ -21,5 +22,20 @@ def create_project_command(project_name):
         print(e)
 
 
+@cli.group('apropos')
+def apropos(*args, **kwargs):
+    pass
+
+
+@apropos.command('tests')
+def apropos_tests_command():
+    help_tests()
+
+
+@apropos.command('install')
+def apropos_install_command():
+    help_install()
+
+
 if __name__ == '__main__':
     cli()
\ No newline at end of file
